@@ -12,7 +12,7 @@ use crate::{
     common::{
         ende::encode_optioned_bytes, BranchID, BranchName, BranchNameOwned, RawKey,
         RawValue, VersionID, VersionName, VersionNameOwned, INITIAL_BRANCH_ID,
-        INITIAL_BRANCH_NAME, INITIAL_VERSION, NULL, RESERVED_VERSION_NUM_DEFAULT, VSDB,
+        INITIAL_BRANCH_NAME, NULL, RESERVED_VERSION_NUM_DEFAULT, VSDB,
     },
 };
 use ruc::*;
@@ -72,7 +72,6 @@ impl MapxRawVs {
             .insert_ref(&INITIAL_BRANCH_ID, INITIAL_BRANCH_NAME.0);
         self.branch_to_its_versions
             .insert(INITIAL_BRANCH_ID, MapxOrd::new());
-        self.version_create(INITIAL_VERSION.0).unwrap();
     }
 
     #[inline(always)]
@@ -540,11 +539,12 @@ impl MapxRawVs {
             .get(&branch_id)
             .c(d!("branch not found"))?
             .remove(&version_id)
-            .is_none()
+            .is_some()
         {
-            return Err(eg!("version is not on this branch"));
+            Ok(())
+        } else {
+            Err(eg!("version is not on this branch"))
         }
-        Ok(())
     }
 
     // # Safety
@@ -716,11 +716,13 @@ impl MapxRawVs {
         &self,
         branch_name: &[u8],
         version_name: &[u8],
+        force: bool,
     ) -> Result<()> {
         self.branch_create_by_base_branch(
             branch_name,
             version_name,
             self.branch_get_default(),
+            force,
         )
         .c(d!())
     }
@@ -731,6 +733,7 @@ impl MapxRawVs {
         branch_name: &[u8],
         version_name: &[u8],
         base_branch_id: BranchID,
+        force: bool,
     ) -> Result<()> {
         let base_version_id = self
             .branch_to_its_versions
@@ -745,6 +748,7 @@ impl MapxRawVs {
             version_name,
             base_branch_id,
             base_version_id,
+            force,
         )
         .c(d!())
     }
@@ -756,6 +760,7 @@ impl MapxRawVs {
         version_name: &[u8],
         base_branch_id: BranchID,
         base_version_id: VersionID,
+        force: bool,
     ) -> Result<()> {
         if self.version_name_to_version_id.contains_key(version_name) {
             return Err(eg!("this version already exists"));
@@ -767,7 +772,9 @@ impl MapxRawVs {
                 Some(version_name),
                 base_branch_id,
                 base_version_id,
+                force,
             )
+            .c(d!())
         }
     }
 
@@ -775,10 +782,12 @@ impl MapxRawVs {
     pub(super) unsafe fn branch_create_without_new_version(
         &self,
         branch_name: &[u8],
+        force: bool,
     ) -> Result<()> {
         self.branch_create_by_base_branch_without_new_version(
             branch_name,
             self.branch_get_default(),
+            force,
         )
         .c(d!())
     }
@@ -788,6 +797,7 @@ impl MapxRawVs {
         &self,
         branch_name: &[u8],
         base_branch_id: BranchID,
+        force: bool,
     ) -> Result<()> {
         let base_version_id = self
             .branch_to_its_versions
@@ -801,6 +811,7 @@ impl MapxRawVs {
             branch_name,
             base_branch_id,
             base_version_id,
+            force,
         )
         .c(d!())
     }
@@ -811,22 +822,34 @@ impl MapxRawVs {
         branch_name: &[u8],
         base_branch_id: BranchID,
         base_version_id: VersionID,
+        force: bool,
     ) -> Result<()> {
         self.do_branch_create_by_base_branch_version(
             branch_name,
             None,
             base_branch_id,
             base_version_id,
+            force,
         )
+        .c(d!())
     }
 
+    // param 'force':
+    // remove the target new branch if it exists
     unsafe fn do_branch_create_by_base_branch_version(
         &self,
         branch_name: &[u8],
         version_name: Option<&[u8]>,
         base_branch_id: BranchID,
         base_version_id: VersionID,
+        force: bool,
     ) -> Result<()> {
+        if force {
+            if let Some(brid) = self.branch_name_to_branch_id.get(branch_name) {
+                self.branch_remove(brid).c(d!())?;
+            }
+        }
+
         if self.branch_name_to_branch_id.contains_key(branch_name) {
             return Err(eg!("branch already exists"));
         }
@@ -865,10 +888,7 @@ impl MapxRawVs {
     // Check if a branch exists or not.
     #[inline(always)]
     pub(super) fn branch_exists(&self, branch_id: BranchID) -> bool {
-        let condition_1 = self.branch_id_to_branch_name.contains_key(&branch_id);
-        let condition_2 = self.branch_to_its_versions.contains_key(&branch_id);
-        assert_eq!(condition_1, condition_2);
-        condition_1
+        self.branch_id_to_branch_name.contains_key(&branch_id)
     }
 
     // Check if a branch exists and has versions on it.
@@ -897,7 +917,6 @@ impl MapxRawVs {
             .c(d!())
             .and_then(|brname| self.branch_name_to_branch_id.remove(&brname).c(d!()))?;
 
-        // we do not call `clear()` on the discarded instance for performance reason.
         self.branch_to_its_versions
             .remove(&branch_id)
             .c(d!())
@@ -1145,6 +1164,7 @@ impl MapxRawVs {
             .filter(|(_, vers)| !vers.is_empty())
             .map(|(_, vers)| vers.iter())
             .collect::<Vec<_>>();
+        alt!(br_vers.is_empty(), return Ok(()));
 
         let last_idx = br_vers.len().saturating_sub(1);
 
