@@ -96,13 +96,58 @@ pub trait VsMgmt {
 
     fn version_exists_globally(&self, version_name: VersionName) -> bool;
 
+    /// # NOTE
+    ///
+    /// The result can only be used as hints, they are unreliable!
+    ///
+    /// For example, there are three Vs-structures:
+    ///
+    /// ```rust,no_run
+    /// struct Vs0(Vs1, Vs2);
+    /// struct Vs1;
+    /// struct Vs2
+    /// ```
+    /// the caller of `Vs0` can NOT guarantee that
+    /// other callers have never created new branches and versions on `Vs1` or `Vs2`,
+    /// so the results returned by `Vs1` and `Vs2` may be different,
+    /// so `Vs0` can NOT guarantee that it can get a completely consistent result.
     fn version_list(&self) -> Result<Vec<VersionNameOwned>>;
 
+    /// # NOTE
+    ///
+    /// The result can only be used as hints, they are unreliable!
+    ///
+    /// For example, there are three Vs-structures:
+    ///
+    /// ```rust,no_run
+    /// struct Vs0(Vs1, Vs2);
+    /// struct Vs1;
+    /// struct Vs2
+    /// ```
+    /// the caller of `Vs0` can NOT guarantee that
+    /// other callers have never created new branches and versions on `Vs1` or `Vs2`,
+    /// so the results returned by `Vs1` and `Vs2` may be different,
+    /// so `Vs0` can NOT guarantee that it can get a completely consistent result.
     fn version_list_by_branch(
         &self,
         branch_name: BranchName,
     ) -> Result<Vec<VersionNameOwned>>;
 
+    /// # NOTE
+    ///
+    /// The result can only be used as hints, they are unreliable!
+    ///
+    /// For example, there are three Vs-structures:
+    ///
+    /// ```rust,no_run
+    /// struct Vs0(Vs1, Vs2);
+    /// struct Vs1;
+    /// struct Vs2
+    /// ```
+    /// the caller of `Vs0` can NOT guarantee that
+    /// other callers have never created new branches and versions on `Vs1` or `Vs2`,
+    /// so the results returned by `Vs1` and `Vs2` may be different,
+    /// so `Vs0` can NOT guarantee that it can get a completely consistent result.
     fn version_list_globally(&self) -> Vec<VersionNameOwned>;
 
     fn version_has_change_set(&self, version_name: VersionName) -> Result<bool>;
@@ -119,6 +164,7 @@ pub trait VsMgmt {
         &self,
         branch_name: BranchName,
         version_name: VersionName,
+        force: bool,
     ) -> Result<()>;
 
     /// Create a new branch based on the head of a specified branch.
@@ -127,6 +173,7 @@ pub trait VsMgmt {
         branch_name: BranchName,
         version_name: VersionName,
         base_branch_name: ParentBranchName,
+        force: bool,
     ) -> Result<()>;
 
     /// Create a new branch based on a specified version of a specified branch.
@@ -136,6 +183,7 @@ pub trait VsMgmt {
         version_name: VersionName,
         base_branch_name: ParentBranchName,
         base_version_name: VersionName,
+        force: bool,
     ) -> Result<()>;
 
     /// # Safety
@@ -145,6 +193,7 @@ pub trait VsMgmt {
     unsafe fn branch_create_without_new_version(
         &self,
         branch_name: BranchName,
+        force: bool,
     ) -> Result<()>;
 
     /// # Safety
@@ -155,6 +204,7 @@ pub trait VsMgmt {
         &self,
         branch_name: BranchName,
         base_branch_name: ParentBranchName,
+        force: bool,
     ) -> Result<()>;
 
     /// # Safety
@@ -166,6 +216,7 @@ pub trait VsMgmt {
         branch_name: BranchName,
         base_branch_name: ParentBranchName,
         base_version_name: VersionName,
+        force: bool,
     ) -> Result<()>;
 
     /// Check if a branch exists or not.
@@ -240,6 +291,21 @@ pub trait VsMgmt {
 
     fn branch_is_empty(&self, branch_name: BranchName) -> Result<bool>;
 
+    /// # NOTE
+    ///
+    /// The result can only be used as hints, they are unreliable!
+    ///
+    /// For example, there are three Vs-structures:
+    ///
+    /// ```rust,no_run
+    /// struct Vs0(Vs1, Vs2);
+    /// struct Vs1;
+    /// struct Vs2
+    /// ```
+    /// the caller of `Vs0` can NOT guarantee that
+    /// other callers have never created new branches and versions on `Vs1` or `Vs2`,
+    /// so the results returned by `Vs1` and `Vs2` may be different,
+    /// so `Vs0` can NOT guarantee that it can get a completely consistent result.
     fn branch_list(&self) -> Vec<BranchNameOwned>;
 
     fn branch_get_default(&self) -> BranchNameOwned;
@@ -402,8 +468,11 @@ macro_rules! impl_vs_methods {
             &self,
             branch_name: BranchName,
             version_name: VersionName,
+            force: bool,
         ) -> Result<()> {
-            self.inner.branch_create(branch_name, version_name).c(d!())
+            self.inner
+                .branch_create(branch_name, version_name, force)
+                .c(d!())
         }
 
         /// Create a new branch based on the head of a specified branch.
@@ -413,12 +482,14 @@ macro_rules! impl_vs_methods {
             branch_name: BranchName,
             version_name: VersionName,
             base_branch_name: ParentBranchName,
+            force: bool,
         ) -> Result<()> {
             self.inner
                 .branch_create_by_base_branch(
                     branch_name,
                     version_name,
                     base_branch_name,
+                    force,
                 )
                 .c(d!())
         }
@@ -431,6 +502,7 @@ macro_rules! impl_vs_methods {
             version_name: VersionName,
             base_branch_name: ParentBranchName,
             base_version_name: VersionName,
+            force: bool,
         ) -> Result<()> {
             self.inner
                 .branch_create_by_base_branch_version(
@@ -438,6 +510,7 @@ macro_rules! impl_vs_methods {
                     version_name,
                     base_branch_name,
                     base_version_name,
+                    force,
                 )
                 .c(d!())
         }
@@ -450,9 +523,10 @@ macro_rules! impl_vs_methods {
         unsafe fn branch_create_without_new_version(
             &self,
             branch_name: BranchName,
+            force: bool,
         ) -> Result<()> {
             self.inner
-                .branch_create_without_new_version(branch_name)
+                .branch_create_without_new_version(branch_name, force)
                 .c(d!())
         }
 
@@ -465,11 +539,13 @@ macro_rules! impl_vs_methods {
             &self,
             branch_name: BranchName,
             base_branch_name: ParentBranchName,
+            force: bool,
         ) -> Result<()> {
             self.inner
                 .branch_create_by_base_branch_without_new_version(
                     branch_name,
                     base_branch_name,
+                    force,
                 )
                 .c(d!())
         }
@@ -484,12 +560,14 @@ macro_rules! impl_vs_methods {
             branch_name: BranchName,
             base_branch_name: ParentBranchName,
             base_version_name: VersionName,
+            force: bool,
         ) -> Result<()> {
             self.inner
                 .branch_create_by_base_branch_version_without_new_version(
                     branch_name,
                     base_branch_name,
                     base_version_name,
+                    force,
                 )
                 .c(d!())
         }
@@ -708,7 +786,7 @@ macro_rules! impl_vs_methods_nope {
         }
 
         #[inline(always)]
-        fn branch_create(&self, _: BranchName, _: VersionName) -> Result<()> {
+        fn branch_create(&self, _: BranchName, _: VersionName, _: bool) -> Result<()> {
             Ok(())
         }
 
@@ -718,6 +796,7 @@ macro_rules! impl_vs_methods_nope {
             _: BranchName,
             _: VersionName,
             _: ParentBranchName,
+            _: bool,
         ) -> Result<()> {
             Ok(())
         }
@@ -729,11 +808,16 @@ macro_rules! impl_vs_methods_nope {
             _: VersionName,
             _: ParentBranchName,
             _: VersionName,
+            _: bool,
         ) -> Result<()> {
             Ok(())
         }
 
-        unsafe fn branch_create_without_new_version(&self, _: BranchName) -> Result<()> {
+        unsafe fn branch_create_without_new_version(
+            &self,
+            _: BranchName,
+            _: bool,
+        ) -> Result<()> {
             Ok(())
         }
 
@@ -741,6 +825,7 @@ macro_rules! impl_vs_methods_nope {
             &self,
             _: BranchName,
             _: ParentBranchName,
+            _: bool,
         ) -> Result<()> {
             Ok(())
         }
@@ -750,6 +835,7 @@ macro_rules! impl_vs_methods_nope {
             _: BranchName,
             _: ParentBranchName,
             _: VersionName,
+            _: bool,
         ) -> Result<()> {
             Ok(())
         }
@@ -1092,9 +1178,10 @@ impl<T: VsMgmt> VsMgmt for Option<T> {
         &self,
         branch_name: BranchName,
         version_name: VersionName,
+        force: bool,
     ) -> Result<()> {
         if let Some(i) = self.as_ref() {
-            i.branch_create(branch_name, version_name).c(d!())?;
+            i.branch_create(branch_name, version_name, force).c(d!())?;
         }
         Ok(())
     }
@@ -1105,10 +1192,16 @@ impl<T: VsMgmt> VsMgmt for Option<T> {
         branch_name: BranchName,
         version_name: VersionName,
         base_branch_name: ParentBranchName,
+        force: bool,
     ) -> Result<()> {
         if let Some(i) = self.as_ref() {
-            i.branch_create_by_base_branch(branch_name, version_name, base_branch_name)
-                .c(d!())?;
+            i.branch_create_by_base_branch(
+                branch_name,
+                version_name,
+                base_branch_name,
+                force,
+            )
+            .c(d!())?;
         }
         Ok(())
     }
@@ -1120,6 +1213,7 @@ impl<T: VsMgmt> VsMgmt for Option<T> {
         version_name: VersionName,
         base_branch_name: ParentBranchName,
         base_version_name: VersionName,
+        force: bool,
     ) -> Result<()> {
         if let Some(i) = self.as_ref() {
             i.branch_create_by_base_branch_version(
@@ -1127,6 +1221,7 @@ impl<T: VsMgmt> VsMgmt for Option<T> {
                 version_name,
                 base_branch_name,
                 base_version_name,
+                force,
             )
             .c(d!())?;
         }
@@ -1136,9 +1231,11 @@ impl<T: VsMgmt> VsMgmt for Option<T> {
     unsafe fn branch_create_without_new_version(
         &self,
         branch_name: BranchName,
+        force: bool,
     ) -> Result<()> {
         if let Some(i) = self.as_ref() {
-            i.branch_create_without_new_version(branch_name).c(d!())?;
+            i.branch_create_without_new_version(branch_name, force)
+                .c(d!())?;
         }
         Ok(())
     }
@@ -1147,11 +1244,13 @@ impl<T: VsMgmt> VsMgmt for Option<T> {
         &self,
         branch_name: BranchName,
         base_branch_name: ParentBranchName,
+        force: bool,
     ) -> Result<()> {
         if let Some(i) = self.as_ref() {
             i.branch_create_by_base_branch_without_new_version(
                 branch_name,
                 base_branch_name,
+                force,
             )
             .c(d!())?;
         }
@@ -1163,12 +1262,14 @@ impl<T: VsMgmt> VsMgmt for Option<T> {
         branch_name: BranchName,
         base_branch_name: ParentBranchName,
         base_version_name: VersionName,
+        force: bool,
     ) -> Result<()> {
         if let Some(i) = self.as_ref() {
             i.branch_create_by_base_branch_version_without_new_version(
                 branch_name,
                 base_branch_name,
                 base_version_name,
+                force,
             )
             .c(d!())?;
         }
