@@ -7,7 +7,7 @@ use crate::{
     common::{
         ende::encode_optioned_bytes, BranchID, BranchName, BranchNameOwned, RawValue,
         VersionID, VersionName, VersionNameOwned, INITIAL_BRANCH_ID,
-        INITIAL_BRANCH_NAME, INITIAL_VERSION, RESERVED_VERSION_NUM_DEFAULT, VSDB,
+        INITIAL_BRANCH_NAME, RESERVED_VERSION_NUM_DEFAULT, VSDB,
     },
 };
 use ruc::*;
@@ -65,7 +65,6 @@ impl MapxRawMkVs {
             .insert_ref(&INITIAL_BRANCH_ID, INITIAL_BRANCH_NAME.0);
         self.branch_to_its_versions
             .insert(INITIAL_BRANCH_ID, MapxOrd::new());
-        self.version_create(INITIAL_VERSION.0).unwrap();
     }
 
     #[inline(always)]
@@ -522,11 +521,13 @@ impl MapxRawMkVs {
         &self,
         branch_name: &[u8],
         version_name: &[u8],
+        force: bool,
     ) -> Result<()> {
         self.branch_create_by_base_branch(
             branch_name,
             version_name,
             self.branch_get_default(),
+            force,
         )
         .c(d!())
     }
@@ -537,6 +538,7 @@ impl MapxRawMkVs {
         branch_name: &[u8],
         version_name: &[u8],
         base_branch_id: BranchID,
+        force: bool,
     ) -> Result<()> {
         let base_version_id = self
             .branch_to_its_versions
@@ -551,6 +553,7 @@ impl MapxRawMkVs {
             version_name,
             base_branch_id,
             base_version_id,
+            force,
         )
         .c(d!())
     }
@@ -562,6 +565,7 @@ impl MapxRawMkVs {
         version_name: &[u8],
         base_branch_id: BranchID,
         base_version_id: VersionID,
+        force: bool,
     ) -> Result<()> {
         if self.version_name_to_version_id.contains_key(version_name) {
             return Err(eg!("this version already exists"));
@@ -573,7 +577,9 @@ impl MapxRawMkVs {
                 Some(version_name),
                 base_branch_id,
                 base_version_id,
+                force,
             )
+            .c(d!())
         }
     }
 
@@ -581,10 +587,12 @@ impl MapxRawMkVs {
     pub(super) unsafe fn branch_create_without_new_version(
         &self,
         branch_name: &[u8],
+        force: bool,
     ) -> Result<()> {
         self.branch_create_by_base_branch_without_new_version(
             branch_name,
             self.branch_get_default(),
+            force,
         )
         .c(d!())
     }
@@ -594,6 +602,7 @@ impl MapxRawMkVs {
         &self,
         branch_name: &[u8],
         base_branch_id: BranchID,
+        force: bool,
     ) -> Result<()> {
         let base_version_id = self
             .branch_to_its_versions
@@ -607,6 +616,7 @@ impl MapxRawMkVs {
             branch_name,
             base_branch_id,
             base_version_id,
+            force,
         )
         .c(d!())
     }
@@ -617,13 +627,16 @@ impl MapxRawMkVs {
         branch_name: &[u8],
         base_branch_id: BranchID,
         base_version_id: VersionID,
+        force: bool,
     ) -> Result<()> {
         self.do_branch_create_by_base_branch_version(
             branch_name,
             None,
             base_branch_id,
             base_version_id,
+            force,
         )
+        .c(d!())
     }
 
     unsafe fn do_branch_create_by_base_branch_version(
@@ -632,7 +645,14 @@ impl MapxRawMkVs {
         version_name: Option<&[u8]>,
         base_branch_id: BranchID,
         base_version_id: VersionID,
+        force: bool,
     ) -> Result<()> {
+        if force {
+            if let Some(brid) = self.branch_name_to_branch_id.get(branch_name) {
+                self.branch_remove(brid).c(d!())?;
+            }
+        }
+
         if self.branch_name_to_branch_id.contains_key(branch_name) {
             return Err(eg!("branch already exists"));
         }
