@@ -1,8 +1,7 @@
 use super::*;
 use crate::{
     common::{
-        BranchName, ParentBranchName, VersionName, VersionNameOwned,
-        INITIAL_BRANCH_NAME, INITIAL_VERSION,
+        BranchName, ParentBranchName, VersionName, VersionNameOwned, INITIAL_BRANCH_NAME,
     },
     ValueEnDe, VsMgmt,
 };
@@ -72,6 +71,8 @@ fn basic_cases() {
 #[allow(non_snake_case)]
 fn VCS_mgmt() {
     let mut hdr = MapxRawMkVs::new(2);
+    pnk!(hdr.version_create(VersionName(b"")));
+
     version_operations(&mut hdr);
     branch_operations(&mut hdr);
     default_branch(&mut hdr);
@@ -267,21 +268,21 @@ fn version_operations(hdr: &mut MapxRawMkVs) {
 }
 
 fn branch_operations(hdr: &mut MapxRawMkVs) {
-    hdr.branch_create(BranchName(b"b-1"), random_version().as_deref())
+    hdr.branch_create(BranchName(b"b-1"), random_version().as_deref(), false)
         .unwrap();
-    hdr.branch_create(BranchName(b"b-2"), random_version().as_deref())
+    hdr.branch_create(BranchName(b"b-2"), random_version().as_deref(), false)
         .unwrap();
 
     assert!(
-        hdr.branch_create(INITIAL_BRANCH_NAME, random_version().as_deref())
+        hdr.branch_create(INITIAL_BRANCH_NAME, random_version().as_deref(), false)
             .is_err()
     );
     assert!(
-        hdr.branch_create(BranchName(b"b-1"), random_version().as_deref())
+        hdr.branch_create(BranchName(b"b-1"), random_version().as_deref(), false)
             .is_err()
     );
     assert!(
-        hdr.branch_create(BranchName(b"b-2"), random_version().as_deref())
+        hdr.branch_create(BranchName(b"b-2"), random_version().as_deref(), false)
             .is_err()
     );
 
@@ -315,6 +316,7 @@ fn branch_operations(hdr: &mut MapxRawMkVs) {
         BranchName(b"b-1-child"),
         random_version().as_deref(),
         ParentBranchName(b"b-1"),
+        false,
     )
     .unwrap();
     assert_eq!(
@@ -346,9 +348,11 @@ fn branch_operations(hdr: &mut MapxRawMkVs) {
 
     // total number of branch has no limits
     (4..2 * BRANCH_LIMITS).for_each(|i| {
-        pnk!(
-            hdr.branch_create(BranchName(&i.to_be_bytes()), random_version().as_deref())
-        );
+        pnk!(hdr.branch_create(
+            BranchName(&i.to_be_bytes()),
+            random_version().as_deref(),
+            false
+        ));
     });
     (4..2 * BRANCH_LIMITS).for_each(|i| {
         pnk!(hdr.branch_remove(BranchName(&i.to_be_bytes())));
@@ -358,7 +362,8 @@ fn branch_operations(hdr: &mut MapxRawMkVs) {
         BranchName(&3usize.to_be_bytes()),
         random_version().as_deref(),
         ParentBranchName(INITIAL_BRANCH_NAME.0),
-        VersionName(b"v-002")
+        VersionName(b"v-002"),
+        false
     ));
     pnk!(hdr.version_create_by_branch(
         VersionName(b"verN"),
@@ -370,7 +375,8 @@ fn branch_operations(hdr: &mut MapxRawMkVs) {
         pnk!(hdr.branch_create_by_base_branch(
             BranchName(&i.to_be_bytes()),
             random_version().as_deref(),
-            ParentBranchName(&(i - 1).to_be_bytes())
+            ParentBranchName(&(i - 1).to_be_bytes()),
+            false
         ));
         pnk!(hdr.version_create_by_branch(
             VersionName(format!("verN_{}", i).as_bytes()),
@@ -381,6 +387,7 @@ fn branch_operations(hdr: &mut MapxRawMkVs) {
         BranchName(&(BRANCH_LIMITS - 2).to_be_bytes()),
         random_version().as_deref(),
         ParentBranchName(&(BRANCH_LIMITS - 3).to_be_bytes()),
+        false,
     ));
     (3..(BRANCH_LIMITS - 1)).rev().for_each(|i| {
         pnk!(hdr.branch_remove(BranchName(&i.to_be_bytes())));
@@ -388,7 +395,8 @@ fn branch_operations(hdr: &mut MapxRawMkVs) {
 
     pnk!(hdr.branch_create(
         BranchName(&1usize.to_be_bytes()),
-        random_version().as_deref()
+        random_version().as_deref(),
+        false
     ));
     pnk!(hdr.branch_remove(BranchName(&1usize.to_be_bytes()),));
 
@@ -484,6 +492,7 @@ fn branch_operations(hdr: &mut MapxRawMkVs) {
             BranchName(&i.to_be_bytes()),
             random_version().as_deref(),
             ParentBranchName(b"b-2"),
+            false,
         )
         .unwrap();
         (1000..1010u64).for_each(|j| {
@@ -544,7 +553,7 @@ fn branch_operations(hdr: &mut MapxRawMkVs) {
 }
 
 fn default_branch(hdr: &mut MapxRawMkVs) {
-    hdr.branch_create(BranchName(b"fork"), random_version().as_deref())
+    hdr.branch_create(BranchName(b"fork"), random_version().as_deref(), false)
         .unwrap();
 
     hdr.branch_set_default(BranchName(b"fork")).unwrap();
@@ -571,7 +580,8 @@ fn default_branch(hdr: &mut MapxRawMkVs) {
         thread::spawn(move || {
             pnk!(h.branch_create(
                 BranchName(&i.to_be_bytes()),
-                random_version().as_deref()
+                random_version().as_deref(),
+                false
             ));
             pnk!(h.branch_set_default(BranchName(&i.to_be_bytes())));
             pnk!(h.version_create(VersionName(format!("ver-on-fork—{}", i).as_bytes())));
@@ -605,6 +615,7 @@ fn prune() {
     pnk!(hdr.prune(None));
     pnk!(hdr.prune(Some(1000000000)));
 
+    pnk!(hdr.version_create(VersionName(b"")));
     pnk!(hdr.insert(&[&[0], &[255]], &[0]));
     pnk!(hdr.version_create(VersionName(b"a")));
     pnk!(hdr.insert(&[&[1], &[255]], &[1]));
@@ -638,6 +649,7 @@ fn prune() {
 
     hdr.clear();
 
+    pnk!(hdr.version_create(VersionName(b"")));
     pnk!(hdr.insert(&[&[0], &[255]], &[0]));
     pnk!(hdr.version_create(VersionName(b"a")));
     pnk!(hdr.insert(&[&[1], &[255]], &[1]));
@@ -650,7 +662,7 @@ fn prune() {
     pnk!(hdr.insert(&[&[6], &[255]], &[6]));
     pnk!(hdr.insert(&[&[7], &[255]], &[7]));
 
-    pnk!(hdr.branch_create(BranchName(b"A"), random_version().as_deref()));
+    pnk!(hdr.branch_create(BranchName(b"A"), random_version().as_deref(), false));
     pnk!(hdr.branch_set_default(BranchName(b"A")));
 
     pnk!(hdr.version_create(VersionName(b"d")));
@@ -664,7 +676,8 @@ fn prune() {
         BranchName(b"B"),
         random_version().as_deref(),
         ParentBranchName(INITIAL_BRANCH_NAME.0),
-        VersionName(b"c")
+        VersionName(b"c"),
+        false
     ));
     pnk!(hdr.branch_set_default(BranchName(b"B")));
 
@@ -729,6 +742,7 @@ fn prune() {
 fn version_rebase() {
     let hdr = MapxRawMkVs::new(2);
 
+    pnk!(hdr.version_create(VersionName(&[0])));
     pnk!(hdr.insert(&[&[0], &[0]], &[0]));
     pnk!(hdr.version_create(VersionName(&[1])));
     pnk!(hdr.insert(&[&[0], &[0]], &[1]));
@@ -744,7 +758,7 @@ fn version_rebase() {
         &pnk!(hdr.get_by_branch_version(
             &[&[0], &[0]],
             INITIAL_BRANCH_NAME,
-            INITIAL_VERSION
+            VersionName(&[0])
         ))[..]
     );
     assert_eq!(
@@ -808,7 +822,7 @@ fn version_rebase() {
         &pnk!(hdr.get_by_branch_version(
             &[&[0], &[0]],
             INITIAL_BRANCH_NAME,
-            INITIAL_VERSION
+            VersionName(&[0])
         ))[..]
     );
     assert_eq!(
@@ -832,7 +846,7 @@ fn version_rebase() {
     assert_eq!(&[4], &pnk!(hdr.get(&[&[0], &[0]]))[..]);
 
     let br = BranchName(&[1]);
-    pnk!(hdr.branch_create(br, random_version().as_deref()));
+    pnk!(hdr.branch_create(br, random_version().as_deref(), false));
 
     pnk!(hdr.version_create_by_branch(VersionName(&[10]), br));
     pnk!(hdr.insert_by_branch(&[&[0], &[0]], &[0], br));
